From: Stefan Beller Date: Thu, 10 Aug 2017 20:33:55 GMT Subject: Re: [PATCH] cache-tree: remove use of strbuf_addf in update_one Message-ID: In-Reply-To: On Thu, Aug 10, 2017 at 12:57 PM, Kevin Willford wrote: > Here are some of the performance numbers from the windows repo. > I will work on writing a perf test for this change so that we > have a better idea on smaller repo what the impact of this change > is on them. > > | w/o | with fix | > ----------------------------------- > git checkout | 36.08 s | 33.34 s | > ----------------------------------- > git checkout | 32.54 s | 28.26 s | > ----------------------------------- > git checkout | 44.10 s | 38.13 s | > ----------------------------------- > git merge | 32.90 s | 30.56 s | > ----------------------------------- > git rebase | 46.14 s | 42.18 s | > ~10-15% is impressive for this patch, I certainly did not expect as much. Thanks for providing the numbers! Stefan